/*
 * uptime.h - part of the uptime module
 *
 * $Id: uptime.h,v 1.10 2003/01/21 00:53:27 wcc Exp $
 */
/*
 * Copyright (C) 2001 proton
 * Copyright (C) 2001, 2002, 2003 Eggheads Development Team
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#ifndef _EGG_MOD_UPTIME_UPTIME_H
#define _EGG_MOD_UPTIME_UPTIME_H

static const int uptime_type = 2;
static const int uptime_port = 9969;
static const char *uptime_host = "uptime.eggheads.org";

#endif /* _EGG_MOD_UPTIME_UPTIME_H */
